@@ -547,13 +547,16 @@ class AbsMilvus:
     """ Memory
     """
 
-    def load_collection(self, collection_name, timeout=None):
+    def load_collection(self, collection_name, db_name, timeout=None):
         """
         Loads a collection for cache.
 
         :type collection_name: str
+
         :param collection_name: collection to load
 
+        :param db_name: db for collection
+
         :return:
             None
 
@@ -634,3 +637,15 @@ class AbsMilvus:
     def wait_index_building_success(self, collection_name, field_name, timeout=30):
 
         pass
+
+    def release_collection(self, collection_name, db_name, timeout=30):
+
+        pass
+
+    def load_partitions(self, db_name, collection_name, partition_names):
+
+        pass
+
+    def release_partitions(self, db_name, collection_name, partition_names):
+
+        pass
