@@ -643,6 +643,7 @@ class GrpcHandler(AbsMilvus):
 
     @error_handler()
     def create_index(self, collection_name, field_name, params, timeout=None, **kwargs):
+        self.flush([collection_name], timeout, **kwargs)
         index_param = Prepare.create_index__request(collection_name, field_name, params)
         future = self._stub.CreateIndex.future(index_param, wait_for_ready=True, timeout=timeout)
         if kwargs.get('_async', False):
@@ -654,8 +655,9 @@ class GrpcHandler(AbsMilvus):
             raise BaseException(status.error_code, status.reason)
         sync = kwargs.get("sync", True)
         if sync:
-            self.wait_index_building_success(collection_name=collection_name, field_name=field_name)
-            self.wait_for_load_index_done(collection_name, timeout, kwargs)
+            if not self.wait_index_building_success(collection_name=collection_name, field_name=field_name):
+                raise BaseException(status.error_code, "create index failed")
+            self.wait_for_load_index_done(collection_name, timeout, **kwargs)
         return Status(status.error_code, status.reason)
 
     @error_handler(None)
@@ -695,7 +697,7 @@ class GrpcHandler(AbsMilvus):
             return response.state
         raise BaseException(status.error_code, status.reason)
 
-    @error_handler()
+    @error_handler(False)
     def wait_index_building_success(self, collection_name, field_name, timeout=30, **kwargs):
         def index_built():
             try:
@@ -706,30 +708,30 @@ class GrpcHandler(AbsMilvus):
         while True:
             time.sleep(0.5)
             print("\n***********  waiting for building index ***********\n")
-            if index_built():
-                break
-
-        return
+            try:
+                state = self.get_index_state(collection_name, field_name, timeout, **kwargs)
+                if state == common_types.IndexState.FINISHED:
+                    return True
+                if state == common_types.IndexState.FAILED:
+                    return False
+            except BaseException:
+                return False
 
     @error_handler()
     def load_collection(self, db_name, collection_name, timeout=None, **kwargs):
         request = Prepare.load_collection(db_name=db_name, collection_name=collection_name)
         rf = self._stub.LoadCollection.future(request, wait_for_ready=True, timeout=timeout)
         response = rf.result()
-        status = response.status
-        if status.error_code == 0:
-            return response.state
-        raise BaseException(status.error_code, status.reason)
+        if response.error_code != 0:
+            raise BaseException(response.error_code, response.reason)
 
     @error_handler()
     def release_collection(self, db_name, collection_name, timeout=30):
         request = Prepare.release_collection(db_name=db_name, collection_name=collection_name)
         rf = self._stub.ReleaseCollection.future(request, wait_for_ready=True, timeout=timeout)
         response = rf.result()
-        status = response.status
-        if status.error_code == 0:
-            return response.state
-        raise BaseException(status.error_code, status.reason)
+        if response.error_code != 0:
+            raise BaseException(response.error_code, response.reason)
 
     @error_handler
     def load_partitions(self, db_name, collection_name, partition_names, timeout=30):
@@ -737,10 +739,8 @@ class GrpcHandler(AbsMilvus):
                                           partition_names=partition_names)
         rf = self._stub.LoadPartitions.future(request, wait_for_ready=True, timeout=timeout)
         response = rf.result()
-        status = response.status
-        if status.error_code == 0:
-            return response.state
-        raise BaseException(status.error_code, status.reason)
+        if response.error_code != 0:
+            raise BaseException(response.error_code, response.reason)
 
     @error_handler
     def release_partitions(self, db_name, collection_name, partition_names, timeout=30):
@@ -748,10 +748,8 @@ class GrpcHandler(AbsMilvus):
                                              partition_names=partition_names)
         rf = self._stub.ReleasePartions().future(request, wait_for_ready=True, timeout=timeout)
         response = rf.result()
-        status = response.status
-        if status.error_code == 0:
-            return response.state
-        raise BaseException(status.error_code, status.reason)
+        if response.error_code != 0:
+            raise BaseException(response.error_code, response.reason)
 
     @error_handler
     def get_collection_stats(self, collection_name, timeout=None, **kwargs):
@@ -776,8 +774,9 @@ class GrpcHandler(AbsMilvus):
     def wait_for_flushed(self, collection_name, timeout=30, **kwargs):
         def flushed():
             try:
-                infos = self.get_persistent_segment_infos(collection_name, timeout, kwargs)
+                infos = self.get_persistent_segment_infos(collection_name, timeout, **kwargs)
                 for info in infos:
+                    print("info.state: ", info.state)
                     if info.state != common_types.SegmentState.SegmentFlushed:
                         return False
                 return True
