@@ -435,7 +435,7 @@ class Milvus:
 
         """
         with self._connection() as handler:
-            stats = handler.get_collection_stats(collection_name, timeout=timeout, **kwargs)
+            stats = handler.get_collection_stats(collection_name, timeout, **kwargs)
             result = {}
             for stat in stats:
                 result[stat.key] = stat.value
